summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/tools/designer/designer/layout.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/tools/designer/designer/layout.cpp')
-rw-r--r--tqtinterface/qt4/tools/designer/designer/layout.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/tqtinterface/qt4/tools/designer/designer/layout.cpp b/tqtinterface/qt4/tools/designer/designer/layout.cpp
index acb6766..e6e34e1 100644
--- a/tqtinterface/qt4/tools/designer/designer/layout.cpp
+++ b/tqtinterface/qt4/tools/designer/designer/layout.cpp
@@ -118,7 +118,7 @@ void Layout::setup()
lastList->append( w );
}
// So, now tqfind the list with the most entries
lastList = 0;
TQValueList<TQWidgetList>::Iterator it = lists.begin();
for ( ; it != lists.end(); ++it ) {
@@ -204,7 +204,7 @@ void Layout::finishLayout( bool needMove, TQLayout *tqlayout )
formWindow->insertWidget( layoutBase );
formWindow->selectWidget( layoutBase );
TQString n = layoutBase->name();
- if ( n.tqfind( "qt_dead_widget_" ) != -1 ) {
+ if ( n.find( "qt_dead_widget_" ) != -1 ) {
n.remove( 0, TQString( "qt_dead_widget_" ).length() );
layoutBase->setName( n );
}
@@ -257,7 +257,7 @@ void Layout::breakLayout()
w->reparent( layoutBase->parentWidget(), 0,
layoutBase->pos() + w->pos(), TRUE );
if ( needResize ) {
- TQMap<TQWidget*, TQRect>::Iterator it = rects.tqfind( w );
+ TQMap<TQWidget*, TQRect>::Iterator it = rects.find( w );
if ( it != rects.end() )
w->setGeometry( TQRect( layoutBase->pos() + (*it).topLeft(), (*it).size() ) );
}
@@ -842,7 +842,7 @@ void GridLayout::buildGrid()
delete grid;
grid = new Grid( (int)(y.size()-1), (int)(x.size()-1) );
- // Mark the cells in the grid that tqcontains a widget
+ // Mark the cells in the grid that contains a widget
for ( w = widgets.first(); w; w = widgets.next() ) {
TQRect c(0,0,0,0), widgetPos = w->tqgeometry();
// From left til right (not including)
@@ -118,7 +118,7 @@ void Layout::setup()
lastList->append( w );
}
- // So, now tqfind the list with the most entries
+ // So, now find the list with the most entries
lastList = 0;
TQValueList<TQWidgetList>::Iterator it = lists.begin();